Ocyan plugin Ocyan Oscar Partner App Plugin
===========================================

About Ocyan Oscar Partner App Plugin
------------------------------------
Ocyan Oscar Partner App Plugin

Installation
------------
Add `ocyan.plugin.oscar_partner` to your projects dependencies.
